Sens
====

*A dynamic Twitch status image generator*

Sens loads data from the Twitch.tv API and writes a png image file.

Requires
--------

* Python 3
* Pillow

Usage
-----

Uninstalled (run via source code)::

    $ python sens [channel_name] [output_file]

Installed::

    $ sens [channel_name] [output_file]
